=======
History
=======

latest
------

* Refactiring the validation approach to use a proper way and not be sticked to
  an specific lxml version


0.3.0
------

* Electronic accounting ready.

  * CoA.
  * Moves.
  * Balance


0.1.0 (2016-1-22)
------------------

* First release on PyPI.
